@@ -9,6 +9,8 @@ use std::io::Read;
 use std::io::Write;
 use url::Url;
 
+use uv_static::EnvVars;
+
 #[derive(Clone, Debug, PartialEq)]
 pub struct Credentials {
     /// The name of the user for authentication.
@@ -139,6 +141,21 @@ impl Credentials {
         })
     }
 
+    /// Extract the [`Credentials`] from the environment, given a named source.
+    ///
+    /// For example, given a name of `"pytorch"`, search for `UV_HTTP_BASIC_PYTORCH_USERNAME` and
+    /// `UV_HTTP_BASIC_PYTORCH_PASSWORD`.
+    pub fn from_env(name: &str) -> Option<Self> {
+        let name = name.to_uppercase();
+        let username = std::env::var(EnvVars::http_basic_username(&name)).ok();
+        let password = std::env::var(EnvVars::http_basic_password(&name)).ok();
+        if username.is_none() && password.is_none() {
+            None
+        } else {
+            Some(Self::new(username, password))
+        }
+    }
+
     /// Parse [`Credentials`] from an HTTP request, if any.
     ///
     /// Only HTTP Basic Authentication is supported.
