@@ -6,12 +6,12 @@ use url::Url;
 use zip::result::ZipError;
 
 use crate::metadata::MetadataError;
-use distribution_filename::WheelFilenameError;
-use pep440_rs::Version;
-use pypi_types::{HashDigest, ParsedUrlError};
 use uv_client::WrappedReqwestError;
+use uv_distribution_filename::WheelFilenameError;
 use uv_fs::Simplified;
 use uv_normalize::PackageName;
+use uv_pep440::Version;
+use uv_pypi_types::{HashDigest, ParsedUrlError};
 
 #[derive(Debug, thiserror::Error)]
 pub enum Error {
@@ -26,7 +26,7 @@ pub enum Error {
     #[error(transparent)]
     ParsedUrl(#[from] ParsedUrlError),
     #[error(transparent)]
-    JoinRelativeUrl(#[from] pypi_types::JoinRelativeError),
+    JoinRelativeUrl(#[from] uv_pypi_types::JoinRelativeError),
     #[error("Expected a file URL, but received: {0}")]
     NonFileUrl(Url),
     #[error(transparent)]
@@ -65,7 +65,7 @@ pub enum Error {
     #[error("Package metadata version `{metadata}` does not match given version `{given}`")]
     VersionMismatch { given: Version, metadata: Version },
     #[error("Failed to parse metadata from built wheel")]
-    Metadata(#[from] pypi_types::MetadataError),
+    Metadata(#[from] uv_pypi_types::MetadataError),
     #[error("Failed to read metadata: `{}`", _0.user_display())]
     WheelMetadata(PathBuf, #[source] Box<uv_metadata::Error>),
     #[error("Failed to read zip archive from built wheel")]
@@ -81,13 +81,13 @@ pub enum Error {
     #[error("The source distribution is missing a `requires.txt` file")]
     MissingRequiresTxt,
     #[error("Failed to extract static metadata from `PKG-INFO`")]
-    PkgInfo(#[source] pypi_types::MetadataError),
+    PkgInfo(#[source] uv_pypi_types::MetadataError),
     #[error("Failed to extract metadata from `requires.txt`")]
-    RequiresTxt(#[source] pypi_types::MetadataError),
+    RequiresTxt(#[source] uv_pypi_types::MetadataError),
     #[error("The source distribution is missing a `pyproject.toml` file")]
     MissingPyprojectToml,
     #[error("Failed to extract static metadata from `pyproject.toml`")]
-    PyprojectToml(#[source] pypi_types::MetadataError),
+    PyprojectToml(#[source] uv_pypi_types::MetadataError),
     #[error("Unsupported scheme in URL: {0}")]
     UnsupportedScheme(String),
     #[error(transparent)]
