@@ -22,6 +22,7 @@ use uv_fs::{LockedFile, Simplified};
 use uv_installer::SitePackages;
 use uv_python::{Interpreter, PythonEnvironment};
 use uv_state::{StateBucket, StateStore};
+use uv_static::EnvVars;
 
 mod receipt;
 mod tool;
@@ -77,7 +78,7 @@ impl InstalledTools {
     /// 2. A directory in the system-appropriate user-level data directory, e.g., `~/.local/uv/tools`
     /// 3. A directory in the local data directory, e.g., `./.uv/tools`
     pub fn from_settings() -> Result<Self, Error> {
-        if let Some(tool_dir) = std::env::var_os("UV_TOOL_DIR") {
+        if let Some(tool_dir) = std::env::var_os(EnvVars::UV_TOOL_DIR) {
             Ok(Self::from_path(tool_dir))
         } else {
             Ok(Self::from_path(
@@ -366,11 +367,11 @@ impl fmt::Display for InstalledTool {
 ///
 /// Errors if a directory cannot be found.
 pub fn find_executable_directory() -> Result<PathBuf, Error> {
-    std::env::var_os("UV_TOOL_BIN_DIR")
+    std::env::var_os(EnvVars::UV_TOOL_BIN_DIR)
         .and_then(dirs_sys::is_absolute_path)
-        .or_else(|| std::env::var_os("XDG_BIN_HOME").and_then(dirs_sys::is_absolute_path))
+        .or_else(|| std::env::var_os(EnvVars::XDG_BIN_HOME).and_then(dirs_sys::is_absolute_path))
         .or_else(|| {
-            std::env::var_os("XDG_DATA_HOME")
+            std::env::var_os(EnvVars::XDG_DATA_HOME)
                 .and_then(dirs_sys::is_absolute_path)
                 .map(|path| path.join("../bin"))
         })
