@@ -7,6 +7,7 @@ use owo_colors::OwoColorize;
 use std::collections::BTreeSet;
 use std::fmt::Write;
 use std::path::Path;
+use tracing::debug;
 
 use uv_client::Connectivity;
 use uv_python::downloads::{DownloadResult, ManagedPythonDownload, PythonDownloadRequest};
@@ -58,7 +59,10 @@ pub(crate) async fn install(
         })
         .collect::<Result<Vec<_>>>()?;
 
-    let installed_installations: Vec<_> = installations.find_all()?.collect();
+    let installed_installations: Vec<_> = installations
+        .find_all()?
+        .inspect(|installation| debug!("Found existing installation {}", installation.key()))
+        .collect();
     let mut unfilled_requests = Vec::new();
     let mut uninstalled = Vec::new();
     for (request, download_request) in requests.iter().zip(download_requests) {
