@@ -27,6 +27,7 @@ use uv_python::managed::ManagedPythonInstallations;
 use uv_python::{
     EnvironmentPreference, PythonInstallation, PythonPreference, PythonRequest, PythonVersion,
 };
+use uv_static::EnvVars;
 
 // Exclude any packages uploaded after this date.
 static EXCLUDE_NEWER: &str = "2024-03-25T00:00:00Z";
@@ -221,7 +222,7 @@ impl TestContext {
     /// returns resolved symlink). This is problematic, as we _don't_ want to resolve symlinks
     /// for user-provided paths.
     pub fn test_bucket_dir() -> PathBuf {
-        env::var("UV_INTERNAL__TEST_DIR")
+        env::var(EnvVars::UV_INTERNAL__TEST_DIR)
             .map(PathBuf::from)
             .unwrap_or_else(|_| {
                 etcetera::base_strategy::choose_base_strategy()
@@ -270,7 +271,7 @@ impl TestContext {
 
         // The workspace root directory is not available without walking up the tree
         // https://github.com/rust-lang/cargo/issues/3946
-        let workspace_root = Path::new(&std::env::var("CARGO_MANIFEST_DIR").unwrap())
+        let workspace_root = Path::new(&std::env::var(EnvVars::CARGO_MANIFEST_DIR).unwrap())
             .parent()
             .expect("CARGO_MANIFEST_DIR should be nested in workspace")
             .parent()
@@ -444,23 +445,23 @@ impl TestContext {
             .arg("--cache-dir")
             .arg(self.cache_dir.path())
             // When running the tests in a venv, ignore that venv, otherwise we'll capture warnings.
-            .env_remove("VIRTUAL_ENV")
-            .env("UV_NO_WRAP", "1")
-            .env("HOME", self.home_dir.as_os_str())
-            .env("UV_PYTHON_INSTALL_DIR", "")
-            .env("UV_TEST_PYTHON_PATH", self.python_path())
-            .env("UV_EXCLUDE_NEWER", EXCLUDE_NEWER)
-            .env_remove("UV_CACHE_DIR")
+            .env_remove(EnvVars::VIRTUAL_ENV)
+            .env(EnvVars::UV_NO_WRAP, "1")
+            .env(EnvVars::HOME, self.home_dir.as_os_str())
+            .env(EnvVars::UV_PYTHON_INSTALL_DIR, "")
+            .env(EnvVars::UV_TEST_PYTHON_PATH, self.python_path())
+            .env(EnvVars::UV_EXCLUDE_NEWER, EXCLUDE_NEWER)
+            .env_remove(EnvVars::UV_CACHE_DIR)
             .current_dir(self.temp_dir.path());
 
         if activate_venv {
-            command.env("VIRTUAL_ENV", self.venv.as_os_str());
+            command.env(EnvVars::VIRTUAL_ENV, self.venv.as_os_str());
         }
 
         if cfg!(all(windows, debug_assertions)) {
             // TODO(konstin): Reduce stack usage in debug mode enough that the tests pass with the
             // default windows stack of 1MB
-            command.env("UV_STACK_SIZE", (4 * 1024 * 1024).to_string());
+            command.env(EnvVars::UV_STACK_SIZE, (4 * 1024 * 1024).to_string());
         }
     }
 
@@ -547,12 +548,12 @@ impl TestContext {
     pub fn help(&self) -> Command {
         let mut command = Command::new(get_bin());
         command.arg("help");
-        command.env_remove("UV_CACHE_DIR");
+        command.env_remove(EnvVars::UV_CACHE_DIR);
 
         if cfg!(all(windows, debug_assertions)) {
             // TODO(konstin): Reduce stack usage in debug mode enough that the tests pass with the
             // default windows stack of 1MB
-            command.env("UV_STACK_SIZE", (4 * 1024 * 1024).to_string());
+            command.env(EnvVars::UV_STACK_SIZE, (4 * 1024 * 1024).to_string());
         }
 
         command
@@ -607,7 +608,7 @@ impl TestContext {
         if cfg!(all(windows, debug_assertions)) {
             // TODO(konstin): Reduce stack usage in debug mode enough that the tests pass with the
             // default windows stack of 1MB
-            command.env("UV_STACK_SIZE", (4 * 1024 * 1024).to_string());
+            command.env(EnvVars::UV_STACK_SIZE, (4 * 1024 * 1024).to_string());
         }
 
         command
@@ -619,8 +620,8 @@ impl TestContext {
         command
             .arg("python")
             .arg("find")
-            .env("UV_PREVIEW", "1")
-            .env("UV_PYTHON_INSTALL_DIR", "")
+            .env(EnvVars::UV_PREVIEW, "1")
+            .env(EnvVars::UV_PYTHON_INSTALL_DIR, "")
             .current_dir(&self.temp_dir);
         self.add_shared_args(&mut command, true);
         command
@@ -632,8 +633,8 @@ impl TestContext {
         command
             .arg("python")
             .arg("pin")
-            .env("UV_PREVIEW", "1")
-            .env("UV_PYTHON_INSTALL_DIR", "")
+            .env(EnvVars::UV_PREVIEW, "1")
+            .env(EnvVars::UV_PYTHON_INSTALL_DIR, "")
             .current_dir(&self.temp_dir);
         self.add_shared_args(&mut command, true);
         command
@@ -650,7 +651,7 @@ impl TestContext {
     /// Create a `uv run` command with options shared across scenarios.
     pub fn run(&self) -> Command {
         let mut command = Command::new(get_bin());
-        command.arg("run").env("UV_SHOW_RESOLUTION", "1");
+        command.arg("run").env(EnvVars::UV_SHOW_RESOLUTION, "1");
         self.add_shared_args(&mut command, true);
         command
     }
@@ -661,7 +662,7 @@ impl TestContext {
         command
             .arg("tool")
             .arg("run")
-            .env("UV_SHOW_RESOLUTION", "1");
+            .env(EnvVars::UV_SHOW_RESOLUTION, "1");
         self.add_shared_args(&mut command, false);
         command
     }
@@ -679,7 +680,7 @@ impl TestContext {
         let mut command = Command::new(get_bin());
         command.arg("tool").arg("install");
         self.add_shared_args(&mut command, false);
-        command.env("UV_EXCLUDE_NEWER", EXCLUDE_NEWER);
+        command.env(EnvVars::UV_EXCLUDE_NEWER, EXCLUDE_NEWER);
         command
     }
 
@@ -1124,13 +1125,13 @@ pub fn run_and_format_with_status<T: AsRef<str>>(
         .to_string();
 
     // Support profiling test run commands with traces.
-    if let Ok(root) = env::var("TRACING_DURATIONS_TEST_ROOT") {
+    if let Ok(root) = env::var(EnvVars::TRACING_DURATIONS_TEST_ROOT) {
         assert!(
             cfg!(feature = "tracing-durations-export"),
             "You need to enable the tracing-durations-export feature to use `TRACING_DURATIONS_TEST_ROOT`"
         );
         command.borrow_mut().env(
-            "TRACING_DURATIONS_FILE",
+            EnvVars::TRACING_DURATIONS_FILE,
             Path::new(&root).join(function_name).with_extension("jsonl"),
         );
     }
@@ -1285,7 +1286,7 @@ pub fn decode_token(content: &[&str]) -> String {
 /// certificate verification, passing through the `BaseClient`
 #[tokio::main(flavor = "current_thread")]
 pub async fn download_to_disk(url: &str, path: &Path) {
-    let trusted_hosts: Vec<_> = std::env::var("UV_INSECURE_HOST")
+    let trusted_hosts: Vec<_> = std::env::var(EnvVars::UV_INSECURE_HOST)
         .unwrap_or_default()
         .split(' ')
         .map(|h| uv_configuration::TrustedHost::from_str(h).unwrap())
